@@ -4,12 +4,12 @@ use strict;
 use vars qw/$VERSION @ISA/;
 use DBIx::dbMan::Extension;
 
-$VERSION = '0.01';
+$VERSION = '0.02';
 @ISA = qw/DBIx::dbMan::Extension/;
 
 1;
 
-sub IDENTIFICATION { return "000001-000046-000001"; }
+sub IDENTIFICATION { return "000001-000046-000002"; }
 
 sub preference { return 2000; }
 
@@ -35,3 +35,11 @@ sub cmdhelp {
 	];
 }
 
+sub cmdcomplete {
+	my ($obj,$text,$line,$start) = @_;
+	return unless $obj->{-dbi}->current;
+	return unless $obj->{-dbi}->driver eq 'Oracle';
+	return qw/ERRORS/ if $line =~ /^\s*SHOW\s+\S*$/i;
+	return qw/SHOW/ if $line =~ /^\s*[A-Z]*$/i;
+	return ();
+}
