@@ -4,12 +4,12 @@ use strict;
 use vars qw/$VERSION @ISA/;
 use DBIx::dbMan::Extension;
 
-$VERSION = '0.03';
+$VERSION = '0.05';
 @ISA = qw/DBIx::dbMan::Extension/;
 
 1;
 
-sub IDENTIFICATION { return "000001-000013-000003"; }
+sub IDENTIFICATION { return "000001-000013-000005"; }
 
 sub preference { return 1000; }
 
@@ -22,7 +22,7 @@ sub handle_action {
 			$action{type} = 'select';
 			$action{sql} = $action{cmd};
 			$action{explain} = 1 if $action{cmd} =~ /^explain\s+/i;
-		} elsif ($action{cmd} =~ /^((delete|insert|update|create|drop|begin|alter|truncate|grant|revoke)\s+.*|vacuum)$/i) {
+		} elsif ($action{cmd} =~ /^((delete|insert|update|create|drop|begin|alter|truncate|grant|revoke|analyze)\s+.*|vacuum)$/i) {
 			$action{action} = 'SQL';
 			$action{type} = 'do';
 			$action{sql} = $action{cmd};
@@ -57,14 +57,17 @@ sub cmdcomplete {
 	return qw/PLAN/ if $line =~ /^\s*EXPLAIN\s+\S*$/i;
 	return $obj->objectlist($1) if $line =~ /^\s*DROP\s+(PACKAGE\s+BODY|\S+)\s+\S*$/i;
 	return qw/WHERE/ if $line =~ /^\s*DELETE\s+FROM\s+\S+\s+\S*$/i;
+	return qw/STATISTICS/ if $line =~ /^\s*ANALYZE\s+TABLE\s+\S+\s+(COMPUTE|ESTIMATE|DELETE)\s+\S*$/i;
+	return ('COMPUTE STATISTICS','ESTIMATE STATISTICS','DELETE STATISTICS') if $line =~ /^\s*ANALYZE\s+TABLE\s+\S+\s+\S*$/i;
 	return qw/SET/ if $line =~ /^\s*UPDATE\s+\S+\s+\S*$/i;
-	return $obj->objectlist('TABLE') if $line =~ /^\s*(TRUNCATE\s+TABLE|DELETE\s+FROM|INSERT\s+INTO|UPDATE|ALTER\s+TABLE)\s+\S*$/i;
+	return $obj->objectlist('TABLE') if $line =~ /^\s*(TRUNCATE\s+TABLE|DELETE\s+FROM|INSERT\s+INTO|UPDATE|ALTER\s+TABLE|ANALYZE\s+TABLE)\s+\S*$/i;
 	return qw/TABLE/ if $line =~ /^\s*TRUNCATE\s+\S*$/i;
 	return qw/FROM/ if $line =~ /^\s*DELETE\s+\S*$/i;
 	return qw/INTO/ if $line =~ /^\s*INSERT\s+\S*$/i;
+	return qw/TABLE INDEX CLUSTER/ if $line =~ /^\s*ANALYZE\s+\S*$/i;
 	return ('BODY',$obj->objectlist('PACKAGE')) if $line =~ /^\s*DROP\s+PACKAGE\s+\S*$/i;
 	return qw/TABLE SEQUENCE VIEW FUNCTION PACKAGE PROCEDURE TRIGGER/ if $line =~ /^\s*(DROP|CREATE|ALTER)\s+\S*$/i;
-	return qw/SELECT EXPLAIN DELETE INSERT UPDATE CREATE DROP BEGIN ALTER TRUNCATE GRANT REVOKE/ if $line =~ /^\s*[A-Z]*$/i;
+	return qw/SELECT EXPLAIN DELETE INSERT UPDATE CREATE DROP BEGIN ALTER TRUNCATE GRANT REVOKE ANALYZE/ if $line =~ /^\s*[A-Z]*$/i;
 	return ($obj->objectlist('CONTEXT',$text),$obj->objectlist('SEQ',$text)) if $line =~ /^\s*(SELECT|DELETE|UPDATE|EXPLAIN)\s+/i;
 }
 
