@@ -4,14 +4,14 @@ use strict;
 use vars qw/$VERSION @ISA/;
 use DBIx::dbMan::Extension;
 
-$VERSION = '0.01';
+$VERSION = '0.02';
 @ISA = qw/DBIx::dbMan::Extension/;
 
 1;
 
-sub IDENTIFICATION { return "000001-000029-000001"; }
+sub IDENTIFICATION { return "000001-000029-000002"; }
 
-sub preference { return 0; }
+sub preference { return 20; }
 
 sub handle_action {
 	my ($obj,%action) = @_;
@@ -20,7 +20,7 @@ sub handle_action {
 	if ($action{action} eq 'SQL_OUTPUT') {
 		for (@{$action{result}}) {
 			for (@$_) {
-				$_ = 'NULL' unless defined $_;
+				$_ = 'NULL' unless defined;
 			}
 		}
 	}
